==> ideaIC-145.1503.17-sources.jar: com/intellij/remote/ext/LanguageCaseCollector.java <==
/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.remote.ext;

import com.intellij.remote.CredentialsType;
import com.intellij.util.ArrayUtil;

import java.util.ArrayList;
import java.util.List;

public abstract class LanguageCaseCollector<T> {

  public CredentialsCase[] collectCases(Class<T> languageContributionClass, CredentialsCase... cases) {
    List<CredentialsCase> exCases = new ArrayList<CredentialsCase>();
    for (final CredentialsLanguageContribution contribution : CredentialsLanguageContribution.EP_NAME.getExtensions()) {
      if (contribution.getLanguageContributionClass() == languageContributionClass) {
        exCases.add(new CredentialsCase() {
          @Override
          public CredentialsType getType() {
            return contribution.getType();
          }

          @Override
          public void process(Object credentials) {
            processLanguageContribution((T)contribution, credentials);
          }
        });
      }
    }

    return ArrayUtil.mergeArrays(cases, exCases.toArray(new CredentialsCase[exCases.size()]));
  }

  protected abstract void processLanguageContribution(T languageContribution, Object credentials);
}

==> ideaIC-171.2014.21-sources.jar: com/intellij/remote/ext/LanguageCaseCollector.java <==
/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.remote.ext;

import com.intellij.remote.CredentialsType;
import com.intellij.util.ArrayUtil;

import java.util.ArrayList;
import java.util.List;

public abstract class LanguageCaseCollector<T> {

  public CredentialsCase[] collectCases(Class<T> languageContributionClass, CredentialsCase... cases) {
    List<CredentialsCase> exCases = new ArrayList<>();
    for (final CredentialsLanguageContribution contribution : CredentialsLanguageContribution.EP_NAME.getExtensions()) {
      if (contribution.getLanguageContributionClass() == languageContributionClass) {
        exCases.add(new CredentialsCase() {
          @Override
          public CredentialsType getType() {
            return contribution.getType();
          }

          @Override
          public void process(Object credentials) {
            processLanguageContribution((T)contribution, credentials);
          }
        });
      }
    }

    return ArrayUtil.mergeArrays(cases, exCases.toArray(new CredentialsCase[exCases.size()]));
  }

  protected abstract void processLanguageContribution(T languageContribution, Object credentials);
}
